@@ -372,7 +372,7 @@ pub trait ConductorHandleT: Send + Sync {
         transition: AppStatusTransition,
     ) -> ConductorResult<(InstalledApp, AppStatusFx)>;
 
-    // TODO: would be nice to have methods for accessing the underlying Conductor,
+    // MAYBE: would be nice to have methods for accessing the underlying Conductor,
     // but this trait doesn't know the concrete type of underlying Conductor,
     // and using generics seems problematic with mockall::automock.
     // Something like this would be desirable, but ultimately doesn't work.
@@ -602,7 +602,8 @@ impl<DS: DnaStore + 'static> ConductorHandleT for ConductorHandleImpl<DS> {
                 ..
             } => {
                 let env = { self.p2p_env(space) };
-                let res = get_agent_info_signed(env, kitsune_space, kitsune_agent)
+                let res = get_agent_info_signed(env.into(), kitsune_space, kitsune_agent)
+                    .await
                     .map_err(holochain_p2p::HolochainP2pError::other);
                 respond.respond(Ok(async move { res }.boxed().into()));
             }
@@ -613,7 +614,8 @@ impl<DS: DnaStore + 'static> ConductorHandleT for ConductorHandleImpl<DS> {
                 ..
             } => {
                 let env = { self.p2p_env(space) };
-                let res = list_all_agent_info(env, kitsune_space)
+                let res = list_all_agent_info(env.into(), kitsune_space)
+                    .await
                     .map(|infos| match agents {
                         Some(agents) => infos
                             .into_iter()
@@ -633,10 +635,15 @@ impl<DS: DnaStore + 'static> ConductorHandleT for ConductorHandleImpl<DS> {
             } => {
                 use holochain_sqlite::db::AsP2pAgentStoreConExt;
                 let env = { self.p2p_env(space) };
-                let res = env
-                    .conn()?
-                    .p2p_gossip_query_agents(since_ms, until_ms, (*arc_set).clone())
-                    .map_err(holochain_p2p::HolochainP2pError::other);
+                let permit = env.conn_permit().await;
+                let res = tokio::task::spawn_blocking(move || {
+                    let mut conn = env.from_permit(permit)?;
+                    conn.p2p_gossip_query_agents(since_ms, until_ms, (*arc_set).clone())
+                })
+                .await;
+                let res = res
+                    .map_err(holochain_p2p::HolochainP2pError::other)
+                    .and_then(|r| r.map_err(holochain_p2p::HolochainP2pError::other));
                 respond.respond(Ok(async move { res }.boxed().into()));
             }
             QueryAgentInfoSignedNearBasis {
@@ -647,9 +654,14 @@ impl<DS: DnaStore + 'static> ConductorHandleT for ConductorHandleImpl<DS> {
                 ..
             } => {
                 let env = { self.p2p_env(space) };
-                let res =
-                    list_all_agent_info_signed_near_basis(env, kitsune_space, basis_loc, limit)
-                        .map_err(holochain_p2p::HolochainP2pError::other);
+                let res = list_all_agent_info_signed_near_basis(
+                    env.into(),
+                    kitsune_space,
+                    basis_loc,
+                    limit,
+                )
+                .await
+                .map_err(holochain_p2p::HolochainP2pError::other);
                 respond.respond(Ok(async move { res }.boxed().into()));
             }
             QueryPeerDensity {
@@ -659,7 +671,8 @@ impl<DS: DnaStore + 'static> ConductorHandleT for ConductorHandleImpl<DS> {
                 ..
             } => {
                 let env = { self.p2p_env(space) };
-                let res = query_peer_density(env, kitsune_space, dht_arc)
+                let res = query_peer_density(env.into(), kitsune_space, dht_arc)
+                    .await
                     .map_err(holochain_p2p::HolochainP2pError::other);
                 respond.respond(Ok(async move { res }.boxed().into()));
             }
@@ -748,10 +761,6 @@ impl<DS: DnaStore + 'static> ConductorHandleT for ConductorHandleImpl<DS> {
                 .await;
             }
 
-            // This event does not have a single Cell as a target, so we handle
-            // it at the conductor level.
-            // TODO: perhaps we can do away with the assumption that each event
-            //       is meant for a single Cell, i.e. allow batching in general
             HolochainP2pEvent::QueryOpHashes {
                 dna_hash,
                 window,
