@@ -1,9 +1,9 @@
 use crate::core::ribosome::CallContext;
+use crate::core::ribosome::HostFnAccess;
 use crate::core::ribosome::RibosomeT;
 use holochain_types::prelude::*;
 use holochain_wasmer_host::prelude::WasmError;
 use std::sync::Arc;
-use crate::core::ribosome::HostFnAccess;
 
 pub fn query(
     _ribosome: Arc<impl RibosomeT>,
@@ -11,18 +11,21 @@ pub fn query(
     input: ChainQueryFilter,
 ) -> Result<Vec<Element>, WasmError> {
     match HostFnAccess::from(&call_context.host_context()) {
-        HostFnAccess{ read_workspace: Permission::Allow, .. } => {
-            tokio_helper::block_forever_on(async move {
-                let elements: Vec<Element> = call_context
-                    .host_context
-                    .workspace()
-                    .source_chain()
-                    .query(input)
-                    .await
-                    .map_err(|source_chain_error| WasmError::Host(source_chain_error.to_string()))?;
-                Ok(elements)
-            })
-        },
+        HostFnAccess {
+            read_workspace: Permission::Allow,
+            ..
+        } => tokio_helper::block_forever_on(async move {
+            let elements: Vec<Element> = call_context
+                .host_context
+                .workspace()
+                .source_chain()
+                .as_ref()
+                .expect("Must have source chain to query the source chain")
+                .query(input)
+                .await
+                .map_err(|source_chain_error| WasmError::Host(source_chain_error.to_string()))?;
+            Ok(elements)
+        }),
         _ => unreachable!(),
     }
 }
@@ -30,7 +33,7 @@ pub fn query(
 #[cfg(test)]
 #[cfg(feature = "slow_tests")]
 pub mod slow_tests {
-    use crate::{fixt::ZomeCallHostAccessFixturator};
+    use crate::fixt::ZomeCallHostAccessFixturator;
     use ::fixt::prelude::*;
     use hdk::prelude::*;
     use query::ChainQueryFilter;
@@ -42,16 +45,19 @@ pub mod slow_tests {
         let host_access = fixt!(ZomeCallHostAccess, Predictable);
 
         let _hash_a: EntryHash =
-            crate::call_test_ribosome!(host_access, TestWasm::Query, "add_path", "a".to_string()).unwrap();
+            crate::call_test_ribosome!(host_access, TestWasm::Query, "add_path", "a".to_string())
+                .unwrap();
         let _hash_b: EntryHash =
-            crate::call_test_ribosome!(host_access, TestWasm::Query, "add_path", "b".to_string()).unwrap();
+            crate::call_test_ribosome!(host_access, TestWasm::Query, "add_path", "b".to_string())
+                .unwrap();
 
         let elements: Vec<Element> = crate::call_test_ribosome!(
             host_access,
             TestWasm::Query,
             "query",
             ChainQueryFilter::default()
-        ).unwrap();
+        )
+        .unwrap();
 
         assert_eq!(elements.len(), 5);
     }
