@@ -172,7 +172,7 @@ async fn mock_network_sharded_gossip() {
         },
     };
     use holochain_p2p::{dht_arc::DhtLocation, AgentPubKeyExt, DnaHashExt};
-    use holochain_sqlite::db::AsP2pAgentStoreConExt;
+    use holochain_sqlite::db::AsP2pStateTxExt;
     use kitsune_p2p::TransportConfig;
     use kitsune_p2p_types::tx2::tx2_adapter::AdapterFactory;
 
@@ -508,7 +508,10 @@ async fn mock_network_sharded_gossip() {
                                             dna,
                                             module,
                                             gossip: GossipProtocol::Sharded(
-                                                ShardedGossipWire::missing_ops(missing_ops, true),
+                                                ShardedGossipWire::missing_ops(
+                                                    missing_ops,
+                                                    MissingOpsStatus::AllComplete as u8,
+                                                ),
                                             ),
                                         };
                                         channel.send(msg.addressed((*agent).clone())).await;
@@ -579,13 +582,13 @@ async fn mock_network_sharded_gossip() {
         let alice_info = alice_info.clone();
         async move {
             loop {
-                let info = alice_p2p_env
-                    .conn()
-                    .unwrap()
-                    .p2p_get_agent(&alice_kit)
-                    .unwrap();
                 {
-                    *alice_info.lock() = info;
+                    let mut conn = alice_p2p_env.conn().unwrap();
+                    let txn = conn.transaction().unwrap();
+                    let info = txn.p2p_get_agent(&alice_kit).unwrap();
+                    {
+                        *alice_info.lock() = info;
+                    }
                 }
                 tokio::time::sleep(std::time::Duration::from_secs(5)).await;
             }
